@@ -12,8 +12,8 @@ from genbase.decorator import add_callargs
 from genbase.internationalization import LOCALE_MAP, get_locale, set_locale, translate_list, translate_string
 from genbase.mixin import CaseMixin, SeedMixin
 from genbase.model import import_model
-from genbase.ui import Render, is_interactive
-from genbase.utils import recursive_to_dict
+from genbase.ui import Render, is_colab, is_interactive
+from genbase.utils import recursive_to_dict, silence_tqdm
 
 
 class Readable:
@@ -194,9 +194,10 @@ class MetaInfo(Configurable):
 
     @property
     def html(self):
-        if 'add_plotly' not in self.renderargs:
-            self.renderargs['add_plotly'] = not is_interactive()
-        return self._renderer(self.to_config()).as_html(**self.renderargs)
+        renderargs = self.renderargs
+        if 'add_plotly' not in renderargs:
+            renderargs['add_plotly'] = not is_interactive() or is_colab()
+        return self._renderer(self.to_config()).as_html(**renderargs)
 
     @property
     def raw_html(self):
